@@ -756,7 +756,7 @@ class Room2D(_BaseGeometry):
         rebuilt_room._properties._duplicate_extension_attr(self._properties)
         return rebuilt_room
 
-    def to_honeybee(self, multiplier=1, tolerance=0.01):
+    def to_honeybee(self, multiplier=1, add_plenum=False, tolerance=0.01):
         """Convert Dragonfly Room2D to a Honeybee Room.
 
         Args:
@@ -765,15 +765,35 @@ class Room2D(_BaseGeometry):
                 on whether you are exporting each room as its own geometry (in which
                 case, this should be 1) or you only want to simulate the "unique" room
                 once and have the results multiplied. Default: 1.
+            add_plenum: Boolean to indicate whether ceiling/floor plenums should
+                be auto-generated for the Room in which case this output will
+                be a list instead of a single Room. The height of the ceiling plenum
+                will be autocalculated as the difference between the Room2D
+                ceiling height and Story ceiling height. The height of the floor
+                plenum will be autocalculated as the difference between the Room2D
+                floor height and Story floor height. (Default: False).
             tolerance: The minimum distance in z values of floor_height and
                 floor_to_ceiling_height at which adjacent Faces will be split.
-                This is also used in the generation of Windows. Default: 0.01,
-                suitable for objects in meters.
+                This is also used in the generation of Windows, and to check if the
+                Room ceiling is adjacent to the upper floor of the Story before
+                generating a plenum. Default: 0.01, suitable for objects in meters.
 
         Returns:
             A tuple with the two items below.
 
-            * hb_room -- A honeybee-core Room representing the dragonfly Room2D
+            * hb_room -- If add_plenum is False, this will be honeybee-core Room
+                representing the dragonfly Room2D. If the add_plenum argument is True,
+                this item will be a list of honeybee-core Rooms, with the hb_room as
+                the first item, and up to two additional items:
+
+                    * ceil_plenum -- A honeybee-core Room representing the ceiling
+                        plenum. If there isn't enough space between the Story
+                        floor_to_floor_height and the Room2D floor_to_ceiling height,
+                        this item will be None.
+
+                    * floor_plenum -- A honeybee-core Room representing the floor plenum.
+                        If there isn't enough space between the Story floor_height and
+                        the Room2D floor_height, this item will be None.
 
             * adjacencies -- A list of tuples that record any adjacencies that
                 should be set on the level of the Story to which the Room2D belongs.
@@ -833,10 +853,23 @@ class Room2D(_BaseGeometry):
         if self._is_top_exposed:
             hb_room[-1].boundary_condition = bcs.outdoors
 
-        # transfer any extension properties assigned to the Room2D
+        # transfer any extension properties assigned to the Room2D and return result
         hb_room._properties = self.properties.to_honeybee(hb_room)
+        if not add_plenum:
+            return hb_room, adjacencies
 
-        return hb_room, adjacencies
+        # add plenums if requested and return results
+        hb_plenums = self._honeybee_plenums(hb_room, tolerance=tolerance)
+        for hb_plenum in hb_plenums:  # transfer the parent's construction set
+            hb_plenum._properties = self.properties.to_honeybee(hb_plenum)
+            try:  # set the program to unconditioned plenum and assign infiltration
+                hb_plenum.properties.energy.program_type = None
+                hb_plenum.properties.energy.hvac = None
+                hb_plenum.properties.energy.infiltration = \
+                    hb_room.properties.energy.infiltration
+            except AttributeError:
+                pass  # honeybee-energy is not loaded; ignore all these energy properties
+        return [hb_room] + hb_plenums, adjacencies
 
     def to_dict(self, abridged=False, included_prop=None):
         """Return Room2D as a dictionary.
@@ -929,7 +962,7 @@ class Room2D(_BaseGeometry):
                                         seg_1.distance_to_point(seg_2.p2) <= tolerance:
                                     # set the boundary conditions of the segments
                                     room_1.set_adjacency(room_2, j, k)
-                                    adj_info.append(((room_1, k), (room_2, k)))
+                                    adj_info.append(((room_1, j), (room_2, k)))
                                     break
             except IndexError:
                 pass  # we have reached the end of the list of zones
@@ -1016,6 +1049,123 @@ class Room2D(_BaseGeometry):
             intersected_rooms.append(rebuilt_room)
         return tuple(intersected_rooms)
 
+    def _honeybee_plenums(self, hb_room, tolerance=0.01):
+        """Get ceiling and/or floor plenums for the Room2D as a Honeybee Room.
+
+        This method will check if there is a gap between the Room2D's ceiling and
+        floor, and the top and bottom of it's corresponding Story, respectively.
+        If there is a gap along the z axis larger then the specified tolerance,
+        it will compute the necessary ceiling and/or floor plenum to fill the gap.
+
+        Args:
+            hb_room: A honeybee Room representing the dragonfly Room2D.
+            tolerance: The minimum distance in z values to check if the Room ceiling
+                and floor is adjacent to the upper and lower floor of the Story,
+                respectively. If not adjacent, the corresponding ceiling or floor
+                plenum is generated. Default: 0.01, suitable for objects in meters.
+
+        Returns:
+            A list of Honeybee Rooms with two items:
+
+                * ceil_plenum -- A honeybee-core Room representing the ceiling
+                    plenum. If there isn't enough space between the Story
+                    floor_to_floor_height and the Room2D floor_to_ceiling height,
+                    this item will be None.
+
+                * floor_plenum -- A honeybee-core Room representing the floor plenum.
+                    If there isn't enough space between the Story floor_height and
+                    the Room2D floor_height, this item will be None.
+        """
+        # check to be sure that the room2d has a parent story
+        hb_rooms = []
+        if not self.has_parent:
+            raise AttributeError(
+                'Cannot add plenums to the "{}" Room because the parent Story has '
+                'not been set. This is required to derive the plenum '
+                'height.'.format(self.identifier))
+
+        parent = self.parent
+        parent_ceiling = parent.floor_height + parent.floor_to_floor_height
+        ceil_plenum_height = parent_ceiling - self.ceiling_height
+        floor_plenum_height = self.floor_height - parent.floor_height
+
+        if ceil_plenum_height > tolerance:
+            ceil_plenum = self._honeybee_plenum(
+                ceil_plenum_height, plenum_type="ceiling")
+            # Set the plenum and the rooms to be adjacent to one another
+            hb_room[-1].set_adjacency(ceil_plenum[0], tolerance)
+            hb_rooms.append(ceil_plenum)
+
+        if floor_plenum_height > tolerance:
+            floor_plenum = self._honeybee_plenum(
+                floor_plenum_height, plenum_type="floor")
+            # Set the plenum and the rooms to be adjacent to one another
+            hb_room[0].set_adjacency(floor_plenum[-1], tolerance)
+            try:
+                hb_room[0].boundary_condition = bcs.adiabatic
+            except AttributeError:
+                pass
+            hb_rooms.append(floor_plenum)
+
+        return hb_rooms
+
+    def _honeybee_plenum(self, plenum_height, plenum_type='ceiling'):
+        """Get a ceiling or floor plenum for the Room2D as a Honeybee Room.
+
+        The boundary condition for all plenum faces is adiabatic except for the
+        ceiling and floor surfaces between the room, and any outdoor walls.
+
+        Args:
+            hb_room: A honeybee Room representing the dragonfly Room2D.
+            plenum_height: The height of the plenum Room.
+            plenum_type: Text for the type of plenum to be constructed.
+                Choose from the following:
+
+                * ceiling
+                * floor
+
+        Returns:
+            A honeybee Room representing a plenum zone.
+        """
+        plenum_id = self.identifier + '_{}_plenum'.format(plenum_type)
+
+        # create reference 2d geometry for plenums
+        ref_face3d = self.floor_geometry.duplicate()
+        if plenum_type == 'ceiling':
+            ref_face3d = ref_face3d.move(Vector3D(0, 0, self.floor_to_ceiling_height))
+        else:
+            ref_face3d = ref_face3d.move(Vector3D(0, 0, -plenum_height))
+
+        # create the honeybee Room
+        plenum_hb_room = Room.from_polyface3d(
+            plenum_id, Polyface3D.from_offset_face(ref_face3d, plenum_height))
+
+        # get the boundary condition that will be used for interior surfaces
+        try:
+            interior_bc = bcs.adiabatic
+        except AttributeError:  # honeybee_energy is not loaded; no Adiabatic BC
+            interior_bc = bcs.outdoors
+
+        # assign wall BCs based on self
+        for i, bc in enumerate(self._boundary_conditions):
+            if not isinstance(bc, Surface):
+                plenum_hb_room[i + 1].boundary_condition = bc
+            else:  # assign boundary conditions for the roof and floor
+                plenum_hb_room[i + 1].boundary_condition = interior_bc
+
+        if plenum_type == 'ceiling':  # assign ceiling BCs
+            if self._is_top_exposed:
+                plenum_hb_room[-1].boundary_condition = bcs.outdoors
+            else:
+                plenum_hb_room[-1].boundary_condition = interior_bc
+        else:  # assign floor BCss
+            if self._is_ground_contact:
+                plenum_hb_room[0].boundary_condition = bcs.ground
+            else:
+                plenum_hb_room[0].boundary_condition = interior_bc
+
+        return plenum_hb_room
+
     def _check_wall_assigned_object(self, value, obj_name=''):
         """Check an input that gets assigned to all of the walls of the Room."""
         try:
